summaryrefslogtreecommitdiff
path: root/lisp/ffap.el
diff options
context:
space:
mode:
authorEli Zaretskii <eliz@gnu.org>2000-12-27 14:08:00 +0000
committerEli Zaretskii <eliz@gnu.org>2000-12-27 14:08:00 +0000
commit6599a0b1f1bc376faa5f5894ef719cd519abd685 (patch)
treed5c3c4a52150a55362c22e5de897c491823aef76 /lisp/ffap.el
parentbb6cbfa9a3b259eaff754e93a8d4f5a6351247a9 (diff)
downloademacs-6599a0b1f1bc376faa5f5894ef719cd519abd685.tar.gz
(ffap-bindings): Make interactive and add an autoload cookie.
(ffap-bindings): Doc fix, to reflect the above change.
Diffstat (limited to 'lisp/ffap.el')
-rw-r--r--lisp/ffap.el8
1 files changed, 4 insertions, 4 deletions
diff --git a/lisp/ffap.el b/lisp/ffap.el
index 22fef574a6e..53eb07392dd 100644
--- a/lisp/ffap.el
+++ b/lisp/ffap.el
@@ -35,9 +35,8 @@
;; README's, MANIFEST's, and so on. Submit bugs or suggestions with
;; M-x ffap-bug.
;;
;; For the default installation, add these two lines to your .emacs file:
;;
-;; (require 'ffap) ; load the package
;; (ffap-bindings) ; do default key bindings
;;
;; ffap-bindings makes the following global key bindings:
@@ -1690,13 +1689,14 @@ ffap most of the time."
;; (setq dired-x-hands-off-my-keys t) ; the default
)
"List of binding forms evaluated by function `ffap-bindings'.
-A reasonable ffap installation needs just these two lines:
- (require 'ffap)
+A reasonable ffap installation needs just these one line:
(ffap-bindings)
Of course if you do not like these bindings, just roll your own!")
+;;;###autoload
(defun ffap-bindings nil
"Evaluate the forms in variable `ffap-bindings'."
+ (interactive)
(eval (cons 'progn ffap-bindings)))
@@ -35,9 +35,8 @@
;; M-x ffap-bug.
;;
-;; For the default installation, add these two lines to your .emacs file:
+;; For the default installation, add this line to your .emacs file:
;;